/**
 * Copyright 2012 Julien Eluard
 * This project includes software developed by Julien Eluard: https://github.com/jeluard/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.github.jeluard.guayaba.base;

import com.google.common.base.Optional;
import com.google.common.base.Preconditions;

/**
 * Helper methods for {@link Optional}.
 */
public final class Optionals {

  private Optionals() {
  }

  /**
   * @param <T>
   * @param optional
   * @return an {@link Optional} returning encapsulated {@link Optional}
   */
  public static <T> Optional<T> flatten(final Optional<Optional<T>> optional) {
    Preconditions.checkNotNull(optional, "null optional");

    if (!optional.isPresent()) {
      return Optional.absent();
    }

    return optional.get();
  }

}