/**
 * Copyright 2012 Julien Eluard
 * This project includes software developed by Julien Eluard: https://github.com/jeluard/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.github.jeluard.guayaba.base;

import com.google.common.base.Preconditions;

/**
 * A simple wrapper for 2 elements.
 */
public final class Pair<T, U> {

  public final T first;
  public final U second;

  public Pair(final T first, final U second) {
    this.first = Preconditions.checkNotNull(first, "null first");
    this.second = Preconditions.checkNotNull(second, "null second");
  }

  @Override
  public int hashCode() {
    int hash = 5;
    hash = 41 * hash + this.first.hashCode();
    hash = 41 * hash + this.second.hashCode();
    return hash;
  }

  @Override
  public boolean equals(final Object object) {
    if (!(object instanceof Pair)) {
      return false;
    }

    final Pair<T, U> other = (Pair<T, U>) object;
    return this.first.equals(other.first) && this.second.equals(other.second);
  }

}