/**
 * Copyright 2012 Julien Eluard
 * This project includes software developed by Julien Eluard: https://github.com/jeluard/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.github.jeluard.guayaba.base;

import com.google.common.base.Preconditions;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

/**
 * Helper methods for {@link Pair}.
 */
public final class Pairs {

  private Pairs() {
  }

  /**
   * @param <U>
   * @param <V>
   * @param pairs
   * @return a {@link Map} composed of all {@code pairs} element
   */
  public static <U, V> Map<U, V> toMap(final Collection<Pair<U, V>> pairs) {
    Preconditions.checkNotNull(pairs, "null pairs");

    final Map<U, V> map = new HashMap<U, V>(pairs.size());
    for (final Pair<U, V> pair : pairs) {
      map.put(pair.first, pair.second);
    }
    return map;
  }

}