/**
 * Copyright 2012 Julien Eluard
 * This project includes software developed by Julien Eluard: https://github.com/jeluard/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.github.jeluard.guayaba.base;

import com.google.common.base.Preconditions;

import java.util.Collection;

/**
 * Extend helper methods from {@link Preconditions}.
 */
public final class Preconditions2 {

  private Preconditions2() {
  }

  /**
   * Ensure specified {@link Collection} is not {@link Collection#isEmpty()}.
   *
   * @param collection a collection
   * @param name a representation of {@code collection} used to build the error message
   * @throws IllegalArgumentException if {@code collection} is {@link Collection#isEmpty()}
   */
  public static <T extends Collection<?>> T checkNotEmpty(final T collection, final String name) {
    Preconditions.checkNotNull(name, "null name");
    Preconditions.checkArgument(!Preconditions.checkNotNull(collection, "null "+name).isEmpty(), name+" is empty");
    return collection;
  }

  /**
   * Ensure specified {@code size} is positive.
   *
   * @param size
   * @return 
   */
  public static int checkSize(final int size) {
    Preconditions.checkArgument(size >= 0, "size must be positive");
    return size;
  }

}