/**
 * Copyright 2012 Julien Eluard
 * This project includes software developed by Julien Eluard: https://github.com/jeluard/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.github.jeluard.guayaba.lang;

import java.lang.Thread.UncaughtExceptionHandler;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Helper methods for {@link UncaughtExceptionHandler}.
 */
public final class UncaughtExceptionHandlers {

  private UncaughtExceptionHandlers() {
  }

  /**
   * @return an {@link UncaughtExceptionHandler} that logs all uncaught {@link Exception}
   */
  public static UncaughtExceptionHandler defaultHandler(final Logger logger) {
    return new UncaughtExceptionHandler() {
      @Override
      public void uncaughtException(final Thread thread, final Throwable throwable) {
        if (logger.isLoggable(Level.WARNING)) {
          logger.log(Level.WARNING, "Got uncaught exception in thread <"+thread.getName()+">", throwable);
        }
      }
    };
  }

}